==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/SAFETYMATRIXID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SAFETYMATRIXID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SAFETYMATRIXID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYMATRIXPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SAFETYMATRIXID_Type", propOrder = {
    "safetymatrixpk",
    "organizationid"
})
public class SAFETYMATRIXID_Type {

    @XmlElement(name = "SAFETYMATRIXPK", required = true)
    protected String safetymatrixpk;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Obtient la valeur de la propriété safetymatrixpk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSAFETYMATRIXPK() {
        return safetymatrixpk;
    }

    /**
     * Définit la valeur de la propriété safetymatrixpk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSAFETYMATRIXPK(String value) {
        this.safetymatrixpk = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/SAFETYMATRIXID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SAFETYMATRIXID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SAFETYMATRIXID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYMATRIXPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SAFETYMATRIXID_Type", propOrder = {
    "safetymatrixpk",
    "organizationid"
})
public class SAFETYMATRIXID_Type {

    @XmlElement(name = "SAFETYMATRIXPK", required = true)
    protected String safetymatrixpk;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Gets the value of the safetymatrixpk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSAFETYMATRIXPK() {
        return safetymatrixpk;
    }

    /**
     * Sets the value of the safetymatrixpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSAFETYMATRIXPK(String value) {
        this.safetymatrixpk = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}
